@@ -5,6 +5,7 @@ from typing import List, Optional, Sequence, Set
 
 from pydantic import BaseModel, validate_arguments
 
+from ..cache import cache
 from ..core import BaseClient
 from ..encoders import encode_query_params
 
@@ -65,6 +66,7 @@ class BaseAlertsResource(ABC):
         return AlertsResponse(**response.json())
 
     @validate_arguments
+    @cache
     async def _get(
         self,
         user_uuid: str,
