@@ -8,7 +8,6 @@ from pydantic import BaseModel, validate_arguments
 from ..cache import cache
 from ..core import BaseClient
 from ..encoders import encode_query_params
-from ..types import AccountType, Currency, Impact
 
 PATH = "/users/{user_uuid}/institutions/{institution_id}/transactions"
 
@@ -17,10 +16,10 @@ class TransactionRecord(BaseModel):
     ts: int
     description: Optional[str]
     amount: int
-    impact: Impact
+    impact: str
     account_id: str
-    account_type: Optional[AccountType]
-    currency: Optional[Currency]
+    account_type: Optional[str]
+    currency: Optional[str]
     labels: Set[str]
 
 
@@ -37,7 +36,7 @@ class TransactionsMeta(BaseModel):
 
 class TransactionsAccount(BaseModel):
     account_id: str
-    account_type: Optional[AccountType]
+    account_type: Optional[str]
     records: List[TransactionRecord]
 
 
@@ -60,7 +59,7 @@ class BaseTransactionsResource(ABC):
         utc_starttime: Optional[datetime] = None,
         utc_endtime: Optional[datetime] = None,
         labels: Optional[Sequence[str]] = None,
-        account_types: Optional[Sequence[AccountType]] = None,
+        account_types: Optional[Sequence[str]] = None,
         page: int = 1,
     ) -> TransactionsResponse:
         async with self._client.session() as session:
@@ -87,7 +86,7 @@ class BaseTransactionsResource(ABC):
         utc_starttime: Optional[datetime] = None,
         utc_endtime: Optional[datetime] = None,
         labels: Optional[Sequence[str]] = None,
-        account_types: Optional[Sequence[AccountType]] = None,
+        account_types: Optional[Sequence[str]] = None,
     ) -> List[TransactionRecord]:
         response = await self._get_page(
             user_uuid=user_uuid,
@@ -133,7 +132,7 @@ class AsyncTransactionsResource(BaseTransactionsResource):
         utc_starttime: Optional[datetime] = None,
         utc_endtime: Optional[datetime] = None,
         labels: Optional[Sequence[str]] = None,
-        account_types: Optional[Sequence[AccountType]] = None,
+        account_types: Optional[Sequence[str]] = None,
     ) -> List[TransactionRecord]:
         return await self._get(
             user_uuid=user_uuid,
@@ -154,7 +153,7 @@ class SyncTransactionsResource(BaseTransactionsResource):
         utc_starttime: Optional[datetime] = None,
         utc_endtime: Optional[datetime] = None,
         labels: Optional[Sequence[str]] = None,
-        account_types: Optional[Sequence[AccountType]] = None,
+        account_types: Optional[Sequence[str]] = None,
     ) -> List[TransactionRecord]:
         return self._client.run(
             self._get(
